eval_loop

Function eval_loop 

pub fn eval_loop(
    source: SourceFile,
    ast: Ast,
    statements: Vec<Statement>,
    user_args_offset: usize,
)
Resolves and evaluates statements, or prints the error and exits.

Only available with the eval feature. Constructs a fresh Evaluator with the stdlib loaded, runs the Resolver pass, then evaluates the program.